<?php

namespace App\Actions\Fortify;

use App\Models\User;
use Exception;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Laravel\Fortify\Contracts\CreatesNewUsers;

class CreateNewUser implements CreatesNewUsers
{
    use PasswordValidationRules;

    /**
     * Validate and create a newly registered user. Only one user is allowed to register.
     *
     * @param  array<string, string>  $input
     *
     * @throws Exception
     */
    public function create(array $input): User
    {
        $websiteAlreadyHasUser = User::count() > 0;
        if ($websiteAlreadyHasUser) {
            throw new Exception('Only one user is allowed to register.');
        }

        Validator::make($input, [
            'name' => ['required', 'string', 'max:255'],
            'email' => [
                'required',
                'string',
                'email',
                'max:255',
                Rule::unique(User::class),
            ],
            'password' => $this->passwordRules(),
        ])->validate();

        return User::create([
            'name' => $input['name'],
            'email' => $input['email'],
            'password' => Hash::make($input['password']),
        ]);
    }
}
