<?php

namespace App\Console\Commands;

use App\Models\UploadedPicture;
use Exception;
use Illuminate\Console\Command;

class OptimizeUploadedPicturesCommand extends Command
{
    protected $signature = 'optimize:uploaded-pictures {--force}';

    protected $description = 'Optimize uploaded pictures by compressing them into different sizes.';

    public function handle(): void
    {
        if ($this->option('force')) {
            $unoptimizedPictures = UploadedPicture::all();
            $this->info('Forcing optimization of '.$unoptimizedPictures->count().' pictures.');
        } else {
            $unoptimizedPictures = UploadedPicture::whereNull(['path_thumbnail', 'path_medium', 'path_big', 'path_fullsize'])->get();
        }

        $this->info('Found '.$unoptimizedPictures->count().' unoptimized pictures.');

        $this->withProgressBar($unoptimizedPictures, function (UploadedPicture $unoptimizedPicture) {
            if ($this->option('force')) {
                $unoptimizedPicture->deleteOptimized();
            }
            try {
                $unoptimizedPicture->optimize();
            } catch (Exception $e) {
                $this->error('Failed to optimize picture with ID '.$unoptimizedPicture->id.': '.$e->getMessage());
            }
        });
    }
}
