<?php

namespace App\Console\Commands;

use App\Models\UploadedPicture;
use App\Services\ImageTranscodingService;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Storage;
use Intervention\Image\Drivers\Imagick\Driver;

class UpdateImageDimensionsCommand extends Command
{
    protected $signature = 'images:update-dimensions';

    protected $description = 'Mise à jour des dimensions (width et height) des images existantes';

    public function __construct()
    {
        parent::__construct();
    }

    public function handle(): void
    {
        $this->info('Mise à jour des dimensions des images...');

        $imageService = new ImageTranscodingService(new Driver);

        $progressBar = $this->output->createProgressBar(UploadedPicture::count());
        UploadedPicture::chunk(100, function ($pictures) use ($progressBar, $imageService) {
            foreach ($pictures as $picture) {
                if (! $picture->path_original) {
                    $this->fail("L'image avec l'ID {$picture->id} n'a pas de chemin original.");
                }

                if (! Storage::disk('public')->exists($picture->path_original)) {
                    $this->fail("Le fichier pour l'image avec l'ID {$picture->id} est introuvable.");
                }

                $dimensions = $imageService->getDimensions(
                    Storage::disk('public')->get($picture->path_original)
                );

                $picture->width = $dimensions['width'];
                $picture->height = $dimensions['height'];
                $picture->save();

                $progressBar->advance();
            }
        });

        $progressBar->finish();

        $this->info('Mise à jour terminée.');
    }
}
