<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\SocialMediaLink;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\View\View;

class SocialMediaLinksController extends Controller
{
    protected array $headerRoutes = [
        [
            'route' => 'admin.social-media-links.index',
            'label' => 'Liste des liens',
            'icon' => 'list',
        ],
        [
            'route' => 'admin.social-media-links.create',
            'label' => 'Ajouter un lien',
            'icon' => 'plus',
        ],
    ];

    public function listPage(): View
    {
        $socialMediaLinks = SocialMediaLink::all();

        return view('admin.social-media-links.index', [
            'headerRoutes' => $this->headerRoutes,
            'socialMediaLinks' => $socialMediaLinks,
        ]);
    }

    public function createPage(): View
    {
        return view('admin.social-media-links.edit', [
            'title' => 'Ajouter un lien',
            'headerRoutes' => $this->headerRoutes,
        ]);
    }

    public function editPage(Request $request, int $id)
    {
        $socialMediaLink = SocialMediaLink::findOrFail($id);

        return view('admin.social-media-links.edit', [
            'title' => 'Modifier un lien',
            'headerRoutes' => $this->headerRoutes,
            'link' => $socialMediaLink,
        ]);
    }

    public function store(Request $request): RedirectResponse
    {
        $request->validate([
            'icon_name' => 'required|string',
            'name' => 'required|string',
            'url' => 'required|url',
        ]);

        $socialMediaLink = SocialMediaLink::create($request->all());

        return redirect()->route('admin.social-media-links.edit', ['socialMediaLink' => $socialMediaLink->id])
            ->with('success', 'Le lien a bien été ajouté.');
    }

    public function update(Request $request): RedirectResponse
    {
        $request->validate([
            'id' => 'required|integer',
            'icon_name' => 'required|string',
            'name' => 'required|string',
            'url' => 'required|url',
        ]);

        $socialMediaLink = SocialMediaLink::findOrFail($request->input('id'));
        $socialMediaLink->update($request->all());

        return redirect()->route('admin.social-media-links.edit', ['socialMediaLink' => $socialMediaLink->id])
            ->with('success', 'Le lien a bien été modifié.');
    }

    public function delete(int $id): RedirectResponse
    {
        SocialMediaLink::destroy($id);

        return redirect()->route('admin.social-media-links.index')
            ->with('success', 'Le lien a bien été supprimé.');
    }
}
