<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Support\Facades\Cache;

class Creation extends CustomBaseModel
{
    use HasFactory;

    public $timestamps = false;

    protected $fillable = [
        'slug',
        'category_id',
        'name_translation_key_id',
        'short_desc_translation_key_id',
        'desc_translation_key_id',
        'cover_uploaded_picture_id',
        'completion_date_start',
        'completion_date_end',
        'tags',
        'is_highlighted',
    ];

    public static function boot(): void
    {
        parent::boot();

        static::saved(function () {
            Cache::forget('creations_highlighted_ordered');
        });

        static::deleted(function () {
            Cache::forget('creations_highlighted_ordered');
        });
    }

    public function nameTranslationKey(): BelongsTo
    {
        return $this->belongsTo(TranslationKey::class, 'name_translation_key_id');
    }

    public function shortDescriptionTranslationKey(): BelongsTo
    {
        return $this->belongsTo(TranslationKey::class, 'short_desc_translation_key_id');
    }

    public function descriptionTranslationKey(): BelongsTo
    {
        return $this->belongsTo(TranslationKey::class, 'desc_translation_key_id');
    }

    public function coverUploadedPicture(): BelongsTo
    {
        return $this->belongsTo(UploadedPicture::class, 'cover_uploaded_picture_id');
    }

    public function category(): BelongsTo
    {
        return $this->belongsTo(Category::class);
    }

    public function creationPictures(): BelongsToMany
    {
        return $this->belongsToMany(UploadedPicture::class, 'creation_pictures');
    }

    public function scopeWithAllRelations($query)
    {
        return $query->with([
            'nameTranslationKey',
            'nameTranslationKey.translations',
            'shortDescriptionTranslationKey',
            'shortDescriptionTranslationKey.translations',
            'descriptionTranslationKey',
            'descriptionTranslationKey.translations',
            'coverUploadedPicture',
            'category',
            'category.nameTranslationKey',
            'category.nameTranslationKey.translations',
            'creationPictures',
        ]);
    }
}
