<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Collection;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Cache;

class CustomBaseModel extends Model
{
    /**
     * Get all records from the model. If the records are already cached, return them.
     *
     * @param  array  $columns
     */
    public static function all($columns = ['*']): Collection
    {
        return Cache::remember(static::class, 3600, function () use ($columns) {
            return parent::all($columns);
        });
    }

    public static function boot(): void
    {
        parent::boot();

        static::saved(function () {
            Cache::forget(static::class);
        });

        static::deleted(function () {
            Cache::forget(static::class);
        });
    }
}
