<?php

namespace App\View\Components;

use Illuminate\Contracts\View\View;
use Illuminate\Support\Facades\Cache;
use Illuminate\View\Component;
use RuntimeException;

class FontAwesome extends Component
{
    public string $type;

    public string $icon;

    /**
     * Crée une nouvelle instance de composant.
     */
    public function __construct(string $icon, string $type = 'regular')
    {
        $this->icon = $icon;
        $this->type = $type;
    }

    /**
     * Récupère le contenu SVG de l'icône.
     */
    public function render(): View
    {
        $cacheKey = "fontawesome.$this->icon.$this->type";

        $svgContent = Cache::rememberForever($cacheKey, function () {
            $iconData = config("fontawesome.$this->icon");

            if (! $iconData) {
                $iconData = config('fontawesome.question');

                if (!$iconData) {
                    throw new RuntimeException("Icon not found: $this->icon, and 'question' icon is also missing.");
                }
            }

            if (! isset($iconData['svg'][$this->type])) {
                if (isset($iconData['svg']['regular'])) {
                    $this->type = 'regular';
                } else {
                    $availableStyles = array_keys($iconData['svg']);
                    $this->type = $availableStyles[0];
                }
            }

            return [
                'path' => $iconData['svg'][$this->type]['path'],
                'viewBox' => $iconData['svg'][$this->type]['viewBox'],
            ];
        });

        return view('components.font-awesome', ['svgContent' => $svgContent]);
    }
}
