<?php

namespace App\View\Components\Public;

use Illuminate\Contracts\View\View;
use Illuminate\Support\Collection;
use Illuminate\Support\Str;
use Illuminate\View\Component;

class CreationMasonry extends Component
{
    public Collection $creations;

    public float $targetHeight;

    public int $columnsCount;

    public bool $allowOverflow;

    public int $gap;

    private float $creationsGap = 0.2;

    public bool $withLinks;

    public function __construct(Collection $creations, float $targetHeight = 1.8, int $columnsCount = 3, bool $allowOverflow = false, int $gap = 4, bool $withLinks = false)
    {
        $this->creations = $creations;
        $this->targetHeight = $targetHeight;
        $this->columnsCount = $columnsCount;
        $this->allowOverflow = $allowOverflow;
        $this->gap = $gap;
        $this->withLinks = $withLinks;
    }

    public function render(): View
    {
        // For each creation, we will calculate the normalized height
        for ($i = 1; $i < $this->creations->count() + 1; $i++) { // The get method is 1-indexed
            if (empty($this->creations->get($i)->coverUploadedPicture->ratio) || ! Str::contains($this->creations->get($i)->coverUploadedPicture->ratio, ':')) {
                $this->creations->forget($i);

                continue;
            }

            $height = Str::afterLast($this->creations->get($i)->coverUploadedPicture->ratio, ':');
            $width = Str::beforeLast($this->creations->get($i)->coverUploadedPicture->ratio, ':');
            $this->creations->get($i)->height = $height / $width;
        }

        $columns = $this->generateMasonryColumns($this->creations, $this->targetHeight, $this->columnsCount, $this->allowOverflow);

        return view('components.public.creation-masonry', compact('columns'));
    }

    private function generateMasonryColumns(Collection $creations, float $targetHeight, int $columnsCount, bool $allowOverflow = false): array
    {
        $columns = array_fill(0, $columnsCount, []);
        foreach ($columns as $key => $column) {
            $columns[$key] = $this->fillColumnWithCreations($creations, $targetHeight, [], $allowOverflow);
            $creations = $creations->diff($columns[$key]);
        }

        return $columns;
    }

    private function fillColumnWithCreations(Collection $creations, float $remainingHeight, array $column = [], bool $allowOverflow = false): array
    {
        $creations = $creations->filter(function ($creation) use ($remainingHeight, $allowOverflow) {
            if ($allowOverflow) {
                return true;
            }

            return $creation->height <= $remainingHeight - $this->creationsGap;
        });

        if ($creations->isEmpty() || $remainingHeight <= 0) {
            return $column;
        }

        $randomlyChosenCreation = $creations->random();

        $column[] = $randomlyChosenCreation;
        $remainingHeight -= $randomlyChosenCreation->height;
        $remainingHeight -= $this->creationsGap;

        $creations = $creations->diff([$randomlyChosenCreation]);

        return $this->fillColumnWithCreations($creations, $remainingHeight, $column);
    }
}
