<?php

namespace Database\Factories;

use App\Models\UploadedPicture;
use Illuminate\Database\Eloquent\Factories\Factory;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Storage;
use Intervention\Image\Drivers\Imagick\Driver;
use Intervention\Image\ImageManager;

class UploadedPictureFactory extends Factory
{
    protected $model = UploadedPicture::class;

    public function definition(): array
    {
        Storage::fake('public');

        return [
            'path_original' => $this->createDummyImage(),
            'path_thumbnail' => $this->createDummyImage(),
            'path_medium' => $this->createDummyImage(),
            'path_big' => $this->createDummyImage(),
            'path_fullsize' => $this->createDummyImage(),
            'ratio' => '1:1',
            'height' => 128,
            'width' => 128,
            'created_at' => Carbon::now(),
            'updated_at' => Carbon::now(),
        ];
    }

    private function createDummyImage(): string
    {
        $manager = new ImageManager(new Driver);
        $image = $manager->create(128, 128)->fill('F78E57');
        $path = 'uploads/'.uniqid().'.jpg';
        Storage::disk('public')->put($path, $image->toJpeg()->toString());

        return $path;
    }
}
