<?php

use App\Models\Prestation;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::table('prestations', function (Blueprint $table) {
            $table->string('slug')->default('')->after('icon_svg');
        });

        $prestations = Prestation::all();
        foreach ($prestations as $prestation) {
            // Normalement, les fallback de ce code ne devraient jamais servir vu que la prod est au-dessus de cette migration
            if ($prestation->nameTransKey()->exists() && ! empty($prestation->nameTransKey->getTranslation(config('app.fallback_locale')))) {
                $proposedSlug = Str::slug($prestation->nameTransKey->getTranslation(config('app.fallback_locale')));

                // Utilisation de la méthode increment pour éviter les conditions de concurrence
                $slug = $proposedSlug;
                $counter = 1;
                while (Prestation::where('slug', $slug)->exists()) {
                    $slug = $proposedSlug.'-'.$counter++;
                }
                $prestation->slug = $slug;
            } else {
                $prestation->slug = uniqid();
            }
            $prestation->save();
        }

        Schema::table('prestations', function (Blueprint $table) {
            $table->string('slug')->unique()->change();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('prestations', function (Blueprint $table) {
            $table->dropColumn('slug');
        });
    }
};
