@extends('layouts.admin', ['title' => $title, 'headerRoutes' => $headerRoutes])

@section('content')
    <div class="grid">
        <div class="g-col-12 g-col-md-6">
            <h5>Information</h5>
            <p>Contrairement au nom de la catégorie, le slug (identifiant unique) n'est pas traductible. Préférez donc
                l'écriture d'un slug dans la langue du pays ciblé par vos prestations, afin de ne pas affecter
                négativement votre référencement sur les moteurs de recherche.</p>
            <form
                    action="{{ !empty($category) ? route('admin.categories.update', $category->id) : route('admin.categories.store') }}"
                    method="post">
                @csrf
                @if(!empty($category))
                    @method('PUT')
                    <input type="hidden" name="id" value="{{ $category->id }}"/>
                @endif

                <x-bs.select
                        id="lang-select"
                        label="Langue"
                        name="lang"
                        :options="['fr' => 'Français', 'en' => 'Anglais']"
                        class="mb-3"
                        :selected="old('lang', $lang ?? 'fr')"
                />

                <x-bs.input
                        id="category-name"
                        label="Nom de la catégorie"
                        name="name"
                        class="mb-3"
                        :value="old('name', $name ?? '')"
                        required
                        data-form-type="other"
                />

                <x-bs.slug-input
                        label="Slug"
                        name="slug"
                        sourceInputId="category-name"
                        class="mb-3"
                        :value="old('slug', !empty($category) ? $category->slug : '')"
                        required
                />

                <x-bs.select
                        label="Couleur"
                        name="color"
                        class="mb-3"
                        :selected="old('color', $category->color ?? 'pink')"
                        :options="collect(\App\Models\Category::COLORS)->mapWithKeys(fn($color) => [$color => $color])"
                        required
                />

                <x-bs.checkbox
                        label="Catégorie mise en avant"
                        name="highlight"
                        class="mb-3"
                        :checked="old('highlight', $category->highlight ?? false)"
                />

                <x-bs.button type="submit">Enregistrer</x-bs.button>
            </form>

            @if (!empty($errors) && $errors->any())
                <x-bs.alert type="danger" class="mt-3">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </x-bs.alert>
            @endif

            @if (session('success'))
                <x-bs.alert type="success" class="mt-3">
                    {{ session('success') }}
                </x-bs.alert>
            @endif
        </div>
    </div>
@endsection

@pushonce('scripts')
    <script type="text/javascript">
        const langSelect = document.getElementById('lang-select');
        const url = new URL(window.location.href);

        if (url.pathname.endsWith('/edit') && !url.searchParams.has('lang') && langSelect) {
            url.searchParams.set('lang', langSelect.value);
            window.location.href = url.toString();
        }

        if (url.pathname.endsWith('/edit') && langSelect) {
            langSelect.addEventListener('change', function () {
                url.searchParams.set('lang', langSelect.value);
                window.location.href = url.toString();
            });
        }
    </script>
@endpushonce