@extends('layouts.admin', ['title' => $title, 'headerRoutes' => $headerRoutes])

@section('content')
    <form action="{{ !empty($creation) ? route('admin.creations.update', $creation->id) : route('admin.creations.store') }}"
          method="post" enctype="multipart/form-data" class="grid">
        <div class="g-col-12 g-col-md-6">
            <h5>Informations</h5>
            <p>Les champs de description sont facultatifs. En revanche, tous les autres sont obligatoires (sauf celui de
                l'image de couverte lors de l'édition).</p>
            <p>La différence entre la courte description et la description est que la courte description doit présenter
                votre création de manière succinte, alors que la description dite "normale" pourra la présenter dans
                tous ses détails. La courte description peut être associée aux descriptions présentées par Google sous
                les résultats de recherche.</p>
            <div>
                @csrf
                @if(!empty($creation))
                    @method('PUT')
                    <input type="hidden" name="id" value="{{ $creation->id }}"/>
                @endif

                @if($categories->isEmpty())
                    <x-bs.alert type="danger" class="mt-3" :dismissible="false">
                        Aucune catégorie n'a été trouvée. Veuillez en ajouter une avant de continuer.
                        <a href="{{ route('admin.categories.create') }}" class="alert-link">Ajouter une catégorie</a>
                    </x-bs.alert>
                @endif

                @if (!empty($errors) && $errors->any())
                    <x-bs.alert type="danger" class="mt-3">
                        <ul>
                            @foreach ($errors->all() as $error)
                                <li>{{ $error }}</li>
                            @endforeach
                        </ul>
                    </x-bs.alert>
                @endif

                @if (session('success'))
                    <x-bs.alert type="success" class="mt-3">
                        {{ session('success') }}
                    </x-bs.alert>
                @endif
                @if (session('error'))
                    <x-bs.alert type="danger" class="mt-3">
                        {{ session('error') }}
                    </x-bs.alert>
                @endif

                <x-bs.select
                        id="lang-select"
                        label="Langue"
                        name="lang"
                        :options="['fr' => 'Français', 'en' => 'Anglais']"
                        class="mb-3"
                        :selected="old('lang', $lang ?? 'fr')"
                />

                <x-bs.input
                        label="Année de début réalisation"
                        name="completion_date_start"
                        type="number"
                        placeholder="Année"
                        class="mb-3"
                        :value="old('completion_date_start', $creation->completion_date_start ?? '')"
                        data-form-type="other"
                />

                <x-bs.input
                        label="Année de fin réalisation"
                        name="completion_date_end"
                        type="number"
                        placeholder="Année"
                        class="mb-3"
                        :value="old('completion_date_end', $creation->completion_date_end ?? '')"
                        data-form-type="other"
                />

                <x-bs.input
                        id="creation-name"
                        label="Nom de la création"
                        name="name"
                        class="mb-3"
                        :value="old('name', $name ?? '')"
                        data-form-type="other"
                        required
                />

                <x-bs.slug-input
                        label="Slug"
                        name="slug"
                        sourceInputId="creation-name"
                        class="mb-3"
                        :value="old('slug', !empty($creation) ? $creation->slug : '')"
                        data-form-type="other"
                        required
                />

                <x-bs.select
                        id="category-select"
                        label="Catégorie"
                        name="category_id"
                        :options="$categories"
                        class="mb-3"
                        :selected="old('category_id', $creation->category_id ?? '')"
                />

                <x-bs.input
                        type="text"
                        label="Tags"
                        name="tags"
                        class="mb-3"
                        :value="old('tags', $creation->tags ?? '')"
                        placeholder="Tag n°1, Tag n°2, ..."
                        data-form-type="other"
                />

                <x-bs.input
                        type="text"
                        label="Courte description"
                        name="short_description"
                        class="mb-3"
                        :value="old('short_description', $shortDescription ?? '')"
                        data-form-type="other"
                />

                <x-admin.markdown-editor
                        label="Description"
                        name="description"
                        class="mb-3"
                        :value="old('description', $description ?? '')"
                        data-form-type="other"
                />

                <x-bs.input
                        type="file"
                        label="Image de couverture"
                        name="cover_image"
                        class="mb-3"
                        :required="empty($creation)"
                />

                <x-bs.checkbox
                        id="is_highlighted"
                        name="is_highlighted"
                        label="Mettre cette création en avant"
                        class="mb-3"
                        :checked="old('is_highlighted', $creation->is_highlighted ?? false)"
                        data-form-type="other"
                />

                <x-bs.button type="submit">Enregistrer</x-bs.button>
            </div>
        </div>
        <div id="pictures-section" class="g-col-12 g-col-md-6">
            <h5>Ajouter des images</h5>
            <p>Vous pouvez ajouter des images à votre création afin de la présenter au mieux.</p>
            <x-bs.input
                    type="file"
                    label="Image additionnelles"
                    name="additional_images[]"
                    accept=".{{ implode(', .', config('app.supported_image_formats')) }}"
                    class="mb-3"
                    multiple
            />

            @if(!empty($creation))
                <h5>Images actuelles</h5>
                <div class="d-flex flex-wrap gap-2">
                    @if($creation->creationPictures->isEmpty())
                        <p>Aucune image n'a été ajoutée à ce
                            projet. {{ \Spatie\Emoji\Emoji::cryingCat() }}</p>
                    @else
                        @foreach($creation->creationPictures as $picture)
                            {{-- TODO: Le faire à la main et ne plus utiliser Vue --}}
                            <picture-preview-input
                                    route="{{ route('admin.creations.remove-additionnal-image', ['creation' => $creation->id, 'image' => $picture->id]) }}"
                                    value="{{ $picture->id }}"
                                    img-src="{{ $picture->getThumbnailSizeUrl() }}"
                                    @image-removed="handleImageRemoved"
                            ></picture-preview-input>
                        @endforeach
                    @endif
                </div>
            @endif
        </div>
    </form>
@endsection

@pushonce('scripts')
    <script type="text/javascript">
        const langSelect = document.getElementById('lang-select');
        const url = new URL(window.location.href);

        if (url.pathname.endsWith('/edit') && !url.searchParams.has('lang') && langSelect) {
            url.searchParams.set('lang', langSelect.value);
            window.location.href = url.toString();
        }

        if (url.pathname.endsWith('/edit') && langSelect) {
            langSelect.addEventListener('change', function () {
                url.searchParams.set('lang', langSelect.value);
                window.location.href = url.toString();
            });
        }
    </script>
    @vite('resources/js/pages/admin/editCreation.js')
@endpushonce