@extends('layouts.admin', ['title' => 'Créations', 'headerRoutes' => $headerRoutes])

@section('content')
    <h5>Information</h5>
    <p>Exposer vos créations aux yeux du publique vous permettra de mieux promouvoir vos services et prestations.</p>

    @if (session('success'))
        <x-bs.alert type="success" class="mt-3">
            {{ session('success') }}
        </x-bs.alert>
    @endif

    <div class="d-flex flex-wrap gap-3">
        @foreach($creations as $creation)
            <x-bs.card imgSrc="{{ $creation->coverUploadedPicture->getMediumSizeUrl() }}"
                       title="{{ $creation->is_highlighted ? \Spatie\Emoji\Emoji::star() : '' }} {{ $creation->nameTranslationKey->getTranslation('fr') }}"
                       :square-img="true"
                       text="{{ $creation->shortDescriptionTranslationKey?->getTranslation('fr') ?? 'Aucune description' }}"
                       :subtitle="empty($creation->completion_date) ? 'Année de réalisation inconnue' : 'Réalisé en ' . $creation->completion_date"
                       :badge-text="$creation->category->nameTranslationKey->getTranslation()"
                       :badge-variant="$creation->is_highlighted ? 'success' : 'secondary'">
                <x-slot:footer>
                    <x-bs.button size="sm" tag="a" href="{{ route('admin.creations.edit', $creation->id) }}"
                                 variant="primary">
                        Modifier
                    </x-bs.button>
                    <x-bs.button href="{{ route('admin.creations.delete', $creation->id) }}"
                                 size="sm" tag="a" variant="danger">
                        Supprimer
                    </x-bs.button>
                    <x-bs.button size="sm" variant="secondary" id="translate-{{ $creation->id }}"
                                 onclick="translateWithAi({{ $creation->id }})">
                        {{ \Spatie\Emoji\Emoji::flagsForFlagUnitedKingdom() }}
                        Traduire
                    </x-bs.button>
                </x-slot:footer>
            </x-bs.card>
        @endforeach
        @if($creations->isEmpty())
            <x-bs.alert type="info" class="mt-3">
                Aucune création n'a été ajoutée pour le moment. {{ \Spatie\Emoji\Emoji::cryingCat() }}
            </x-bs.alert>
        @endif
    </div>
@endsection

@pushonce('scripts')
    <script type="text/javascript">
        function translateWithAi(creationId) {
            const button = document.querySelector(`#translate-${creationId}`);
            button.disabled = true;
            fetch(`/admin/creations/${creationId}/translate-with-ai`)
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        button.classList.remove('btn-secondary');
                        button.classList.add('btn-success');
                    } else {
                        button.disabled = false;
                        button.classList.remove('btn-secondary');
                        button.classList.add('btn-warning');
                    }
                });
        }
    </script>
@endpushonce
