@extends('layouts.admin', ['title' => $title, 'headerRoutes' => $headerRoutes])

@section('content')
    <form action="{{ !empty($event) ? route('admin.events.update', $event->id) : route('admin.events.store') }}"
          method="post" enctype="multipart/form-data" class="grid">
        <div class="g-col-12 g-col-md-6">
            <h5>Informations sur l'Évènement</h5>
            @csrf
            @if(!empty($event))
                @method('PUT')
                <input type="hidden" name="id" value="{{ $event->id }}"/>
            @endif

            @if (!empty($errors) && $errors->any())
                <x-bs.alert type="danger" class="mt-3">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </x-bs.alert>
            @endif

            @if (session('success'))
                <x-bs.alert type="success" class="mt-3">
                    {{ session('success') }}
                </x-bs.alert>
            @endif
            @if (session('error'))
                <x-bs.alert type="danger" class="mt-3">
                    {{ session('error') }}
                </x-bs.alert>
            @endif

            <x-bs.select
                    id="lang-select"
                    label="Langue"
                    name="lang"
                    :options="['fr' => 'Français', 'en' => 'Anglais']"
                    class="mb-3"
                    :selected="old('lang', $lang ?? 'fr')"
            />

            <x-bs.input
                    id="event-name"
                    label="Nom de l'évènement"
                    name="name"
                    class="mb-3"
                    :value="old('name', $name ?? '')"
                    required
            />

            <x-bs.slug-input
                    label="Slug"
                    name="slug"
                    sourceInputId="event-name"
                    class="mb-3"
                    :value="old('slug', $event->slug ?? '')"
                    required
            />

            <x-bs.input
                    type="date"
                    label="Date de Début"
                    name="date_start"
                    class="mb-3"
                    :value="old('date_start', (!empty($event) ? $event->date_start->format('Y-m-d') : ''))"
                    required
            />

            <x-bs.input
                    type="date"
                    label="Date de Fin"
                    name="date_end"
                    class="mb-3"
                    :value="old('date_end', (!empty($event) ? $event->date_end->format('Y-m-d') : ''))"
                    required
            />

            <x-bs.input
                    label="Ville"
                    name="city"
                    class="mb-3"
                    :value="old('city', $event->city ?? '')"
                    required
            />

            <x-bs.input
                    type="file"
                    label="Image de couverture"
                    name="image"
                    class="mb-3"
                    :required="empty($event)"
            />

            <x-bs.button type="submit">Enregistrer</x-bs.button>
        </div>
    </form>
@endsection

@pushonce('scripts')
    <script type="text/javascript">
        const langSelect = document.getElementById('lang-select');
        const url = new URL(window.location.href);

        if (url.pathname.endsWith('/edit') && !url.searchParams.has('lang') && langSelect) {
            url.searchParams.set('lang', langSelect.value);
            window.location.href = url.toString();
        }

        if (url.pathname.endsWith('/edit') && langSelect) {
            langSelect.addEventListener('change', function () {
                url.searchParams.set('lang', langSelect.value);
                window.location.href = url.toString();
            });
        }
    </script>
@endpushonce