@extends('layouts.admin', ['title' => 'Administration'])

@section('content')
    <div class="container" id="admin-home">
        @if(\App\Models\DbConfig::get('maintenance_mode', 'true'))
            <x-bs.alert type="warning" :dismissible="false" icon="info" title="Information" style="max-width: none;">
                Le site est masqué au public car le mode maintenance est activé.<br>
                <a href="{{ route('admin.settings.update-website-config') }}" class="alert-link">
                    Rendez-vous sur la page de configuration du site pour le désactiver.
                </a>
            </x-bs.alert>
        @endif
        <h3 class="mb-4">Statistiques des Visites uniques</h3>

        <div class="grid mb-4">
            <!-- Total des visites -->
            <div class="g-col-12 g-col-md-6 g-col-lg-3">
                <div class="card text-center">
                    <div class="card-body">
                        <h5 class="card-title">Total des visites</h5>
                        <p class="display-6 fw-bold">{{ $totalVisitsAllTime }}</p>
                    </div>
                </div>
            </div>
            <div class="g-col-12 g-col-md-6 g-col-lg-3">
                <div class="card text-center">
                    <div class="card-body">
                        <h5 class="card-title">Visites depuis 30 jours</h5>
                        <p class="display-6 fw-bold">{{ $totalVisitsPastThirtyDays }}</p>
                    </div>
                </div>
            </div>
            <div class="g-col-12 g-col-md-6 g-col-lg-3">
                <div class="card text-center">
                    <div class="card-body">
                        <h5 class="card-title">Visites depuis 7 jours</h5>
                        <p class="display-6 fw-bold">{{ $totalVisitsPastSevenDays }}</p>
                    </div>
                </div>
            </div>
            <div class="g-col-12 g-col-md-6 g-col-lg-3">
                <div class="card text-center">
                    <div class="card-body">
                        <h5 class="card-title">Visites aujourd'hui</h5>
                        <p class="display-6 fw-bold">{{ $totalVisitsPastTwentyFourHours }}</p>
                    </div>
                </div>
            </div>
        </div>

        <div class="grid mb-4">
            <div class="g-col-12 g-col-md-6 g-col-lg-3">
                <x-bs.select id="statsSelect" label="Période de statistiques" name="period"
                             :options="$periods" :selected="$selectedPeriod"/>
            </div>
        </div>

        <div class="row mb-4">
            <!-- Visites par jour -->
            <div class="g-col-md-6 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Visites par jour</h5>
                        <div id="visits-per-day-chart">
                            <visits-per-day-chart :data="{{ json_encode($visitsPerDay) }}"></visits-per-day-chart>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Visites par pays -->
            <div class="g-col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Visites par pays</h5>
                        <div id="visits-by-country-chart">
                            <visits-by-country-chart
                                    :data="{{ json_encode($visitsByCountry) }}"></visits-by-country-chart>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="row g-4">
            <!-- Pages les plus visitées -->
            <div class="g-col-12 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Pages les plus visitées</h5>
                        <div class="table-responsive">
                            <table class="table table-striped align-middle">
                                <thead>
                                <tr>
                                    <th scope="col">#</th>
                                    <th scope="col">Page</th>
                                    <th scope="col">Nombre de visites</th>
                                </tr>
                                </thead>
                                <tbody>
                                @foreach ($mostVisitedPages as $index => $page)
                                    <tr>
                                        <th scope="row">{{ $index + 1 }}</th>
                                        <td>{{ $page['url'] }}</td>
                                        <td>{{ $page['count'] }}</td>
                                    </tr>
                                @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Meilleurs referers -->
            <div class="g-col-12 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">
                            Referers (sites référents) les plus fréquents
                        </h5>
                        <div class="table-responsive">
                            <table class="table table-striped align-middle">
                                <thead>
                                <tr>
                                    <th scope="col">#</th>
                                    <th scope="col">Referer</th>
                                    <th scope="col">Nombre de visites</th>
                                </tr>
                                </thead>
                                <tbody>
                                @foreach ($bestsReferrers as $index => $referer)
                                    <tr>
                                        <th scope="row">{{ $index + 1 }}</th>
                                        <td>{{ $referer['url'] }}</td>
                                        <td>{{ $referer['count'] }}</td>
                                    </tr>
                                @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Meilleures origines -->
            <div class="g-col-12">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Origines les plus fréquentes</h5>
                        <div class="table-responsive">
                            <table class="table table-striped align-middle">
                                <thead>
                                <tr>
                                    <th scope="col">#</th>
                                    <th scope="col">Origine</th>
                                    <th scope="col">Nombre de visites</th>
                                </tr>
                                </thead>
                                <tbody>
                                @foreach ($bestOrigins as $index => $origin)
                                    <tr>
                                        <th scope="row">{{ $index + 1 }}</th>
                                        <td>{{ $origin['url'] }}</td>
                                        <td>{{ $origin['count'] }}</td>
                                    </tr>
                                @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    @vite('resources/js/pages/admin/home.js')
@endsection
