@extends('layouts.admin', ['title' => $title, 'headerRoutes' => $headerRoutes])

@section('content')
    <form action="{{ !empty($prestation) ? route('admin.prestations.update', $prestation->id) : route('admin.prestations.store') }}"
          method="post" enctype="multipart/form-data" class="grid">
        <div class="g-col-12 g-col-md-6">
            <h5>Informations sur la Prestation</h5>
            <p>
                <strong>Note :</strong> Les icônes recommandées sont les icônes FontAwesome Light.
                Vous pouvez les trouver ici <a href="https://fontawesome.com/search?o=r&s=light" target="_blank">https://fontawesome.com/search?o=r&s=light</a>.
                Il faudra les télécharger (bouton
                <x-font-awesome icon="arrow-down-to-line" height="1rem"/>
                en haut à droite)
                au format SVG et les ajouter ici.
            </p>
            <p>
                Vous n'êtes pas obligé de vous restreindre à ces icônes, mais assurez-vous que l'icône que vous
                choisissez garde une cohérence avec les autres icônes du site.
            </p>
            @csrf
            @if(!empty($prestation))
                @method('PUT')
                <input type="hidden" name="id" value="{{ $prestation->id }}"/>
            @endif

            @if(!empty($creation))
                @method('PUT')
                <input type="hidden" name="id" value="{{ $creation->id }}"/>
            @endif

            @if($categories->isEmpty())
                <x-bs.alert type="danger" class="mt-3" :dismissible="false">
                    Aucune catégorie n'a été trouvée. Veuillez en ajouter une avant de continuer.
                    <a href="{{ route('admin.categories.create') }}" class="alert-link">Ajouter une catégorie</a>
                </x-bs.alert>
            @endif

            @if (!empty($errors) && $errors->any())
                <x-bs.alert type="danger" class="mt-3">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </x-bs.alert>
            @endif

            @if (session('success'))
                <x-bs.alert type="success" class="mt-3">
                    {{ session('success') }}
                </x-bs.alert>
            @endif
            @if (session('error'))
                <x-bs.alert type="danger" class="mt-3">
                    {{ session('error') }}
                </x-bs.alert>
            @endif

            <x-bs.select
                    id="lang-select"
                    label="Langue"
                    name="lang"
                    :options="['fr' => 'Français', 'en' => 'Anglais']"
                    class="mb-3"
                    :selected="old('lang', $lang ?? 'fr')"
            />

            <x-bs.input
                    id="prestation-name"
                    label="Nom de la prestation"
                    name="name"
                    class="mb-3"
                    :value="old('name', $name ?? '')"
                    required
            />

            <x-bs.slug-input
                    label="Slug"
                    name="slug"
                    sourceInputId="prestation-name"
                    class="mb-3"
                    :value="old('slug', !empty($prestation) ? $prestation->slug : '')"
                    required/>

            <x-bs.select
                    id="category-select"
                    label="Catégorie"
                    name="category_id"
                    :options="$categories"
                    class="mb-3"
                    :selected="old('category_id', $prestation->category_id ?? '')"
            />

            <x-bs.input
                    type="text"
                    label="Détail (pour les cartes de la page d'accueil)"
                    name="detail"
                    class="mb-3"
                    :value="old('detail', $prestation->detail ?? '')"
                    data-form-type="other"
            />

            <x-bs.textarea
                    label="Description Attrayante"
                    name="attract_desc"
                    class="mb-3"
                    :value="old('attract_desc', $attractionDesc ?? '')"
            />

            <x-admin.markdown-editor
                    label="Description Contenu"
                    name="content_desc"
                    class="mb-3"
                    :value="old('content_desc', $contentDesc ?? '')"
                    required
            />

            <x-bs.input
                    type="file"
                    label="Icône SVG"
                    name="icon_svg"
                    class="mb-3"
                    accept=".svg"
            />

            <x-bs.input
                    type="file"
                    label="Image de couverture"
                    name="cover_image"
                    class="mb-3"
            />

            <x-bs.button type="submit">Enregistrer</x-bs.button>
        </div>
    </form>
@endsection

@pushonce('scripts')
    <script type="text/javascript">
        const langSelect = document.getElementById('lang-select');
        const url = new URL(window.location.href);

        if (url.pathname.endsWith('/edit') && !url.searchParams.has('lang') && langSelect) {
            url.searchParams.set('lang', langSelect.value);
            window.location.href = url.toString();
        }

        if (url.pathname.endsWith('/edit') && langSelect) {
            langSelect.addEventListener('change', function () {
                url.searchParams.set('lang', langSelect.value);
                window.location.href = url.toString();
            });
        }
    </script>
@endpushonce