@extends('layouts.admin', ['title' => 'Utilisateurs', 'headerRoutes' => $headerRoutes])

@section('content')
    @if($isSuperAdmin)
        <h5>Gérer les accès à votre administration</h5>
        <p>Vous pouvez inviter des personnes à accéder à votre panneau d'administration en leur envoyant une invitation
            par
            email.</p>
        <p><span class="fw-bold text-danger">Attention !</span> Pour des raisons de simplicité, ces personnes auront les
            mêmes droits que vous (sauf toutes les actions liées à cette page et à la configuration du site, y compris
            leur accès).
            <strong>Soyez bien certains d'avoir confiance en elles !</strong></p>

        <x-bs.button data-bs-toggle="modal" data-bs-target="#addUserModal" size="sm" variant="primary">
            Ajouter un utilisateur
        </x-bs.button>

        @if (session('success'))
            <x-bs.alert type="success" class="mt-3">
                {{ session('success') }}
            </x-bs.alert>
        @endif

        @if (session('error'))
            <x-bs.alert type="danger" class="mt-3">
                {{ session('error') }}
            </x-bs.alert>
        @endif

        @if (!empty($errors) && $errors->any())
            <x-bs.alert type="danger" class="mt-3">
                <ul>
                    @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </x-bs.alert>
        @endif

        <table class="table">
            <thead>
            <tr>
                <th scope="col">ID</th>
                <th scope="col">Nom</th>
                <th scope="col">Adresse e-mail</th>
                <th scope="col">S'est déjà connecté ?</th>
                <th scope="col">Utilise la double Authentification ?</th>
                <th scope="col">Date d'ajout</th>
                <th scope="col">Actions</th>
            </tr>
            </thead>
            <tbody>
            @foreach($users as $user)
                <tr>
                    <th scope="row">{{ $user->id }}</th>
                    <td>{{ $user->name }}</td>
                    <td>{{ $user->email }}</td>
                    <td>{{ $user->alreadyConnected ? 'Oui' : 'Non' }}</td>
                    <td>{{ !empty($user->two_factor_confirmed_at) ? 'Oui' : 'Non' }}</td>
                    <td>{{ $user->created_at->format('d/m/Y H:i') }}</td>
                    <td>
                        <x-bs.button href="{{ route('admin.settings.delete-user', $user->id) }}"
                                     size="sm" tag="a" variant="danger">
                            Supprimer
                        </x-bs.button>
                    </td>
                </tr>
            @endforeach
            </tbody>
        </table>
    @else
        <div class="alert alert-danger" role="alert">
            Vous n'avez pas les droits nécessaires pour accéder à cette page.
        </div>
    @endif
@endsection

@push('scripts')
    <div class="modal fade" id="addUserModal" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1"
         aria-labelledby="staticBackdropLabel" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" action="{{ route('admin.settings.create-user') }}" method="post">
                @csrf
                <div class="modal-header">
                    <h1 class="modal-title fs-5" id="staticBackdropLabel">Ajouter un utilisateur</h1>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <p>L'utilisateur recevra un mail d'invitation. Pour se connecter, il devra faire une demande de
                        réinitialisation de mot de passe.</p>

                    <x-bs.input name="name" type="text" label="Nom" class="mb-3" required/>
                    <x-bs.input name="email" type="email" label="Adresse e-mail" required/>
                </div>
                <div class="modal-footer">
                    <x-bs.button variant="secondary" data-bs-dismiss="modal">
                        Annuler
                    </x-bs.button>
                    <x-bs.button type="submit" variant="primary">
                        Ajouter
                    </x-bs.button>
                </div>
            </form>
        </div>
    </div>
@endpush