@extends('layouts.admin', ['title' => $title, 'headerRoutes' => $headerRoutes])

@section('content')
    <div class="grid">
        <div class="g-col-12 g-col-md-6">
            <h5>Information</h5>
            <p>Gérez les conditions générales de vente.</p>

            <form action="{{ !empty($section) ? route('admin.terms.update', $section->id) : route('admin.terms.store') }}"
                  method="post">
                @csrf
                @if(!empty($section))
                    @method('PUT')
                @endif

                <x-bs.select id="lang-select" label="Langue" name="lang"
                             :options="['fr' => 'Français', 'en' => 'Anglais']"
                             class="mb-3" :selected="old('lang', $lang ?? 'fr')"/>

                <x-admin.markdown-editor label="Contenu" name="content" class="mb-3"
                                         :value="old('content', $content ?? '')"
                                         required/>

                <x-bs.checkbox name="active" label="Activer cette section" :checked="old('active', $active ?? false)"
                               class="mb-3"/>

                <x-bs.button type="submit">Enregistrer</x-bs.button>
            </form>

            @if (!empty($errors) && $errors->any())
                <x-bs.alert type="danger" class="mt-3">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </x-bs.alert>
            @endif

            @if (session('success'))
                <x-bs.alert type="success" class="mt-3">
                    {{ session('success') }}
                </x-bs.alert>
            @endif
        </div>
    </div>
@endsection

@pushonce('scripts')
    <script type="text/javascript">
        const langSelect = document.getElementById('lang-select');
        const url = new URL(window.location.href);

        if (url.pathname.endsWith('/edit') && !url.searchParams.has('lang') && langSelect) {
            url.searchParams.set('lang', langSelect.value);
            window.location.href = url.toString();
        }

        if (url.pathname.endsWith('/edit') && langSelect) {
            langSelect.addEventListener('change', function () {
                url.searchParams.set('lang', langSelect.value);
                window.location.href = url.toString();
            });
        }
    </script>
@endpushonce
