@extends('layouts.public', ['description' => __('home.meta_description')])

@section('content')
    <section class="HeroSection position-relative w-100">
        <div class="container mx-auto px-4">
            <x-public.navbar :socialMediaLinks="$socialMediaLinks"/>

            <!-- Hero Content -->
            <div class="flex w-full justify-center gap-16 items-center py-8">
                <div class="MetaContainer flex flex-col shrink-0 w-full xl:w-[36rem] h-[38rem]">
                    <div class="flex flex-col grow shrink-0 basis-0 justify-center items-start">
                        <div class="flex relative flex-col justify-start items-start gap-24">
                            <x-public.star
                                    class="absolute hidden 2xl:block left-[-120px] top-[-96px] origin-top-left rotate-[6deg] w-12"/>
                            <x-public.star
                                    class="absolute hidden 2xl:block left-[-96px] top-[-26px] origin-top-left rotate-[-22deg] w-16"/>
                            <h1 class="flex flex-col justify-start items-start">
                                <span class="flex justify-start items-center gap-4">
                                    <span class="text-xl xl:text-3xl font-normal">
                                        {{ __('home.hero.first_row') }}
                                    </span>
                                    <x-public.arrow class="hidden xl:block w-28 h-9"/>
                                </span>
                                <span class="text-5xl xl:text-6xl">
                                    {{ __('home.hero.second_row') }}
                                </span>
                            </h1>
                            <x-public.button size="large" tag="a" href="{{ route('contact') }}"
                                             class="flex items-center gap-8">
                                <img class="w-10 h-10" src="{{Vite::asset("resources/images/public/waving-hand.avif")}}"
                                     alt="{{ __('home.img_alt.waving_hand') }}" loading="eager"/>
                                <div class="flex flex-col justify-center items-start">
                                    <div class="font-bold leading-6">
                                        {{ __('home.hero.btn.title') }}
                                    </div>
                                    <div class="font-normal">
                                        {{ __('home.hero.btn.description') }}
                                    </div>
                                </div>
                            </x-public.button>
                        </div>
                    </div>
                    <div class="relative flex flex-col gap-4">
                        <x-public.star
                                class="absolute hidden xl:block left-[552px] top-[50px] origin-top-left rotate-[-2deg] w-20"/>
                        <div class="flex flex-col">
                            <div class="text-2xl font-bold">
                                {{ __('home.hero.my_specialities') }}
                            </div>
                        </div>
                        <div class="flex flex-wrap items-center gap-2">
                            @foreach($categories as $category)
                                <x-public.button :variant="$category->color" tag="a" name="{{ $category->slug }}"
                                                 :href="route('portfolio', ['category_id' => $category->id])">
                                {{ $category->nameTranslationKey->getTranslation() }}
                                </x-public.button>
                            @endforeach
                        </div>
                    </div>
                </div>

                <x-public.creation-masonry :creations="$creations" :target-height="1.5" :columns-count="3"
                                           :allow-overflow="true" with-links
                                           class="Creations relative hidden xl:grid grow w-full aspect-[885/622]"/>
            </div>
        </div>
        <img class="HeroGrid absolute -z-10 left-0 top-0 w-100" alt="Image de fond"
             src="{{Vite::asset("resources/images/public/hero-grid.avif")}}"/>
    </section>

    <section class="AboutMeSection position-relative w-full flex flex-col justify-start items-center pb-24 bg-light">
        <div class="w-full h-24 bg-gradient-to-b from-neutral-200 to-light"></div>
        <div class="container mx-auto px-4 flex flex-col justify-start items-center gap-2.5">
            <div class="flex flex-col justify-start items-start w-full gap-16">
                <div class="flex flex-col xl:flex-row justify-start w-full gap-8 xl:gap-16">
                    <div class="flex shrink-0 justify-center items-center p-4 xl:p-0 gap-2.5">
                        <div class="overflow-hidden w-full xl:w-[25rem] aspect-square rounded-2xl shadow-[-.5rem_.5rem_0px_0px_rgba(0,0,0,1.00)] shadow-pink-normal">
                            @if(!$aboutMeSection->isEmpty())
                                <img class="w-full h-full object-cover"
                                     alt="{{ __('home.img_alt.roxannas_photo') }}"
                                     src="{{ $aboutMeSection->first()->uploadedPicture->getBigSizeUrl() }}"/>
                            @else
                                <img class="w-full h-full object-cover"
                                     alt="{{ __('home.img_alt.roxannas_photo') }}"
                                     src="https://via.placeholder.com/464x464"/>
                            @endif
                        </div>
                    </div>
                    <div class="flex flex-col py-2.5 items-start gap-4">
                        <div class="text-2xl font-bold">{{ __('home.about_me') }}</div>
                        <h2 class="text-5xl xl:text-6xl font-normal mb-8">
                            @if(!$aboutMeSection->isEmpty())
                                {{ $aboutMeSection->first()->attractDescTransKey->getTranslation() }}
                            @else
                                Lorem ipsum dolor sit amet,
                            @endif
                        </h2>

                        <x-markdown class="flex flex-col gap-3 text-muted text-xl xl:text-2xl font-normal">
                            @if(!$aboutMeSection->isEmpty())
                                {{ $aboutMeSection->first()->contentTransKey->getTranslation() }}
                            @else
                                Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed do eiusmod tempor
                                incididunt ut labore et dolore magna aliqua.
                            @endif
                        </x-markdown>
                    </div>
                </div>
            </div>
        </div>
    </section>

    <section class="PrestationsSection flex py-24" aria-label="{{ __('home.my_services') }}">
        <div class="container mx-auto px-4 flex flex-col gap-16">
            <div class="flex flex-col max-w-6xl">
                <div class="text-2xl font-bold">{{ __('home.my_services') }}</div>
                <h2 class="text-5xl xl:text-6xl font-normal">{{ __('home.services_attract_desc') }}</h2>
            </div>
            <div class="grid grid-cols-1 md:grid-cols-2 xl:grid-cols-4 justify-center items-center gap-8">
                @foreach($prestations as $prestation)
                    <x-public.prestation-card :prestation="$prestation"/>
                @endforeach
            </div>
        </div>
    </section>

    <x-public.footer/>
@endsection