<?php

namespace Tests\Feature\Console\Commands;

use App\Console\Commands\FlushUnusedUploadedPicturesCommand;
use App\Models\UploadedPicture;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Storage;
use PHPUnit\Framework\Attributes\CoversClass;
use Tests\TestCase;

#[CoversClass(FlushUnusedUploadedPicturesCommand::class)]
class FlushUnusedUploadedPicturesCommandTest extends TestCase
{
    use RefreshDatabase;

    public function test_command_handles_no_unused_pictures()
    {
        $this->artisan('flush:unused-uploaded-pictures')
            ->expectsOutput('Found 0 unused pictures')
            ->assertSuccessful();
    }

    public function test_command_flushes_unused_pictures()
    {
        Storage::fake('public');

        $unusedPicture = UploadedPicture::factory()->create();
        Storage::disk('public')->put($unusedPicture->path_original, 'dummy content');

        $this->artisan('flush:unused-uploaded-pictures')
            ->expectsOutput('Found 1 unused pictures')
            ->assertSuccessful();

        $this->assertDatabaseMissing('uploaded_pictures', ['id' => $unusedPicture->id]);
    }
}
