<?php

namespace Tests\Feature\Console\Commands;

use App\Console\Commands\OptimizeUploadedPicturesCommand;
use App\Models\UploadedPicture;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Storage;
use PHPUnit\Framework\Attributes\CoversClass;
use Tests\TestCase;

/**
 * Tests de la commande d'optimisation des images uploadées
 */
#[CoversClass(OptimizeUploadedPicturesCommand::class)]
class OptimizeUploadedPicturesCommandTest extends TestCase
{
    use RefreshDatabase;

    public function test_command_handles_no_unoptimized_pictures()
    {
        $this->artisan('optimize:uploaded-pictures')
            ->expectsOutput('Found 0 unoptimized pictures.')
            ->assertSuccessful();
    }

    public function test_command_optimizes_unoptimized_pictures()
    {
        Storage::fake('public');

        $picture = UploadedPicture::factory()->create([
            'path_thumbnail' => null,
            'path_medium' => null,
            'path_big' => null,
            'path_fullsize' => null,
        ]);

        $this->artisan('optimize:uploaded-pictures')
            ->expectsOutput('Found 1 unoptimized pictures.')
            ->assertSuccessful();

        $this->assertNotNull($picture->fresh()->path_thumbnail);
        $this->assertNotNull($picture->fresh()->path_medium);
        $this->assertNotNull($picture->fresh()->path_big);
        $this->assertNotNull($picture->fresh()->path_fullsize);
    }
}
