<?php

namespace Tests\Feature\Console\Commands;

use App\Console\Commands\UpdateImageDimensionsCommand;
use App\Models\UploadedPicture;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Storage;
use Intervention\Image\Drivers\Imagick\Driver;
use Intervention\Image\ImageManager;
use PHPUnit\Framework\Attributes\CoversClass;
use Tests\TestCase;

/**
 * Tests de la commande de mise à jour des dimensions des images
 */
#[CoversClass(UpdateImageDimensionsCommand::class)]
class UpdateImageDimensionsCommandTest extends TestCase
{
    use RefreshDatabase;

    public function test_command_updates_image_dimensions(): void
    {
        Storage::fake('public');

        $imagePath = 'uploads/test_image.jpg';

        $uploadedPicture = UploadedPicture::factory()->create([
            'path_original' => $imagePath,
            'width' => 0,
            'height' => 0,
        ]);

        $imageContent = (new ImageManager(new Driver))->create(128, 128)->fill('F78E57')->toJpeg()->toString();

        Storage::disk('public')->put($imagePath, $imageContent);

        $this->artisan('images:update-dimensions')->assertSuccessful();

        $uploadedPicture->refresh();

        $this->assertEquals(128, $uploadedPicture->width);
        $this->assertEquals(128, $uploadedPicture->height);
        Storage::disk('public')->assertExists($imagePath);
    }

    public function test_command_skips_missing_files(): void
    {
        $uploadedPicture = UploadedPicture::factory()->create([
            'path_original' => 'uploads/missing_image.jpg',
            'width' => '',
            'height' => '',
        ]);

        Artisan::call(UpdateImageDimensionsCommand::class);

        $uploadedPicture->refresh();

        $this->assertEquals('', $uploadedPicture->width);
        $this->assertEquals('', $uploadedPicture->height);
    }
}
