<?php

namespace Tests\Feature\Controller;

use App\Http\Controllers\Admin\EventController;
use App\Models\Event;
use Carbon\Carbon;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;
use PHPUnit\Framework\Attributes\CoversClass;
use Tests\TestCase;

#[CoversClass(EventController::class)] class EventTest extends TestCase
{
    use RefreshDatabase, WithoutMiddleware;

    public function test_it_can_create_an_event()
    {
        Storage::fake('public');
        $response = $this->post('/admin/events', [
            'lang' => 'fr',
            'name' => 'Nouvel Évènement',
            'slug' => 'nouvel-evenement',
            'date_start' => Carbon::now()->toDateString(),
            'date_end' => Carbon::now()->addDays(2)->toDateString(),
            'city' => 'Paris',
            'image' => UploadedFile::fake()->image('image.jpg'),
        ]);

        $response->assertRedirect(route('admin.events.edit', ['event' => 1]));
        $this->assertDatabaseHas('events', [
            'slug' => 'nouvel-evenement',
            'city' => 'Paris',
        ]);

        $this->assertDatabaseHas('translations', [
            'text' => 'Nouvel Évènement',
            'locale' => 'fr',
        ]);

        $this->assertDatabaseHas('uploaded_pictures', [
            'id' => 1,
        ]);
    }

    public function test_it_can_update_an_event()
    {
        Storage::fake('public');
        $event = Event::factory()->create();

        $response = $this->put("/admin/events/$event->id", [
            'lang' => 'fr',
            'name' => 'Évènement Modifié',
            'slug' => 'evenement-modifie',
            'date_start' => Carbon::now()->toDateString(),
            'date_end' => Carbon::now()->addDays(3)->toDateString(),
            'city' => 'Lyon',
            'image' => UploadedFile::fake()->image('image.jpg'),
        ]);

        $response->assertRedirect(route('admin.events.edit', ['event' => $event->id]));
        $this->assertDatabaseHas('events', [
            'id' => $event->id,
            'slug' => 'evenement-modifie',
            'city' => 'Lyon',
        ]);

        $this->assertDatabaseHas('translations', [
            'text' => 'Évènement Modifié',
            'locale' => 'fr',
        ]);

        $this->assertDatabaseHas('uploaded_pictures', [
            'id' => 2,
        ]);
    }

    public function test_it_can_delete_an_event()
    {
        Storage::fake('public');
        $event = Event::factory()->create();

        $response = $this->get("/admin/events/$event->id/delete");

        $response->assertRedirect(route('admin.events.index'));
        $this->assertDatabaseMissing('events', [
            'id' => $event->id,
        ]);
    }
}
