<?php

namespace Tests\Feature\Controller;

use App\Http\Controllers\Admin\SocialMediaLinksController;
use App\Models\SocialMediaLink;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use PHPUnit\Framework\Attributes\CoversClass;
use Tests\TestCase;

#[CoversClass(SocialMediaLinksController::class)] class SocialMediaLinksControllerTest extends TestCase
{
    use RefreshDatabase, WithoutMiddleware;

    public function test_it_can_list_social_media_links()
    {
        SocialMediaLink::factory()->count(3)->create();

        $response = $this->get(route('admin.social-media-links.index'));

        $response->assertStatus(200);
        $response->assertViewIs('admin.social-media-links.index');
        $response->assertViewHas('socialMediaLinks');
        $this->assertCount(3, $response->viewData('socialMediaLinks'));
    }

    public function test_it_can_create_a_social_media_link()
    {
        $data = [
            'icon_name' => 'facebook',
            'name' => 'Facebook',
            'url' => 'https://facebook.com',
        ];

        $response = $this->post(route('admin.social-media-links.store'), $data);

        $response->assertRedirect(route('admin.social-media-links.edit', ['socialMediaLink' => 1]));
        $this->assertDatabaseHas('social_media_links', $data);
    }

    public function test_it_can_edit_a_social_media_link()
    {
        $link = SocialMediaLink::factory()->create();

        $response = $this->get(route('admin.social-media-links.edit', ['socialMediaLink' => $link->id]));

        $response->assertStatus(200);
        $response->assertViewIs('admin.social-media-links.edit');
        $response->assertViewHas('link', $link);
    }

    public function test_it_can_update_a_social_media_link()
    {
        $link = SocialMediaLink::factory()->create();

        $data = [
            'id' => $link->id,
            'icon_name' => 'twitter',
            'name' => 'Twitter',
            'url' => 'https://twitter.com',
        ];

        $response = $this->put(route('admin.social-media-links.update', ['socialMediaLink' => $link->id]), $data);

        $response->assertRedirect(route('admin.social-media-links.edit', ['socialMediaLink' => $link->id]));
        $this->assertDatabaseHas('social_media_links', $data);
    }

    public function test_it_can_delete_a_social_media_link()
    {
        $link = SocialMediaLink::factory()->create();

        $response = $this->get(route('admin.social-media-links.delete', ['socialMediaLink' => $link->id]));

        $response->assertRedirect(route('admin.social-media-links.index'));
        $this->assertDatabaseMissing('social_media_links', ['id' => $link->id]);
    }
}
